@@ -2,7 +2,7 @@ import pickle
 import os
 
 
-def get_data(file_name):
+def getData(file_name):
     print(os.path.abspath(__file__))
 
     data_path = os.path.abspath(__file__).replace("__init__.py", file_name)
